# Tutorial: Python

## Prerequisites

1. [Install Ibis Birdbrain](/install.qmd)

## Overview

You can use Ibis Birdbrain as a Python library, but it is often used through an
interactive Python session. You can [see how to start one with the `birdbrain`
CLI with Ibis Birdbrain ready to use](/tutorials/cli.qmd).

## Next steps

Explore some data with Ibis Birdbrain and [let us know how it
goes!](https://github.com/ibis-project/ibis-birdbrain/issues/new)
